--[[************************************************************************************************************************************************************
	
	exhaustCap specialization v1.1 (compatible with MR)
	
	10/2013 by Saty / http://forum.lsczech.cz
	
****************************************************************************************************************************************************************
	
	(EN) INFO
	
	Free for use on mods. Modifications only with my permission !
	
****************************************************************************************************************************************************************
	
	(CZ) INFO
	
	Pro volne pouziti v modech. ZAKAZ modifikaci bez meho souhlasu !
	
	--------------------------------------------------------------------------------------------------------------------------------------------------------	
	
	Zapis do XML souboru stroje :
	*****************************
	
	<exhaustCap index="11|0" minRotX="0" maxRotX="90" rotTime="0.5" />
	
	
	Vysvetlivky k funkcim:
	
	node				- index klapky v GE
	minRotX				- uhel klapky pri zavreni
	maxRotX				- uhel klapky pri plnem otevreni
	rotTime				- doba za kterou se klapka otevre z min do max
	
	--------------------------------------------------------------------------------------------------------------------------------------------------------	
	
	Zapis do souboru modDesc.xml :
	******************************
	
	vsadit do <specializations> :
		<specialization name="exhaustCap"  className="exhaustCap"  filename="scripts/exhaustCap.lua"/>
	
	vsadit do <vehicleTypes> :
		<specialization name="exhaustCap" />
	
************************************************************************************************************************************************************]]--

exhaustCap = {};

function exhaustCap.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function exhaustCap:load(xmlFile)
	local capNode = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.exhaustCap#index"));
	if capNode ~= nil then
		self.cap = {};
		self.cap.node = capNode;
		
		self.cap.minRot = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.exhaustCap#minRotX")), 0);
		self.cap.maxRot = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.exhaustCap#maxRotX")), 0);
		
		self.cap.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.exhaustCap#rotTime"), 2)*1000;
	end;
end;

function exhaustCap:delete()
end;

function exhaustCap:mouseEvent(posX, posY, isDown, isUp, button)
end;

function exhaustCap:keyEvent(unicode, sym, modifier, isDown)
end;

function exhaustCap:update(dt)
	local x, y, z, rot, capAngle = {};
	
	if self.isMotorStarted and self.cap ~= nil then
		x, y, z = getRotation(self.cap.node);
		rot = {x,y,z};
		if self.motor.isRealistic then
			capAngle = self.cap.minRot + ((math.random(0, 150) + (RealisticUtils.linearFx(self.realLastMotorFx^0.5, 300, 2200) * 1.8) - 500) * 0.001);
		else
			capAngle = self.cap.minRot + ((math.random(0, 150) + (self.motor.lastMotorRpm * 1.8) - 500) * 0.001);
		end;
		if capAngle < self.cap.minRot then
			capAngle = self.cap.minRot;
		elseif capAngle > self.cap.maxRot then
			capAngle = self.cap.maxRot;
		end;
		local newRot = Utils.getMovedLimitedValues(rot, {180,y,z}, {capAngle,y,z}, 3, 60000, dt, true);
		setRotation(self.cap.node, unpack(newRot));
	else
		x, y, z = getRotation(self.cap.node);
		rot = {x,y,z};
		newRot = Utils.getMovedLimitedValues(rot, {self.cap.minRot,y,z}, {self.cap.maxRot,y,z}, 3, self.cap.rotTime, dt, false);
		setRotation(self.cap.node, unpack(newRot));
	end;
end;

function exhaustCap:draw()
end;